@@ -8,10 +8,10 @@
 #include "mediacontrols.h"
 #include "mediacontrols_p.h"
 
-#include <phonon/mediaobject.h>
-#include <phonon/audiooutput.h>
 #include <QBoxLayout>
 #include <QToolButton>
+#include <phonon/audiooutput.h>
+#include <phonon/mediaobject.h>
 #include <phonon/seekslider.h>
 #include <phonon/volumeslider.h>
 
@@ -19,8 +19,8 @@ namespace Phonon
 {
 
 MediaControls::MediaControls(QWidget *parent)
-    : QWidget(parent),
-      d_ptr(new MediaControlsPrivate(this))
+    : QWidget(parent)
+    , d_ptr(new MediaControlsPrivate(this))
 {
     setMaximumHeight(32);
 }
@@ -47,16 +47,14 @@ void MediaControls::setMediaObject(MediaObject *media)
     Q_D(MediaControls);
     if (d->media) {
         disconnect(d->media, SIGNAL(destroyed()), this, SLOT(_k_mediaDestroyed()));
-        disconnect(d->media, SIGNAL(stateChanged(Phonon::State,Phonon::State)), this,
-                   SLOT(_k_stateChanged(Phonon::State,Phonon::State)));
+        disconnect(d->media, SIGNAL(stateChanged(Phonon::State, Phonon::State)), this, SLOT(_k_stateChanged(Phonon::State, Phonon::State)));
         disconnect(&d->playButton, SIGNAL(clicked()), d->media, SLOT(play()));
         disconnect(&d->pauseButton, SIGNAL(clicked()), d->media, SLOT(pause()));
     }
     d->media = media;
     if (media) {
         connect(media, SIGNAL(destroyed()), SLOT(_k_mediaDestroyed()));
-        connect(media, SIGNAL(stateChanged(Phonon::State,Phonon::State)),
-                SLOT(_k_stateChanged(Phonon::State,Phonon::State)));
+        connect(media, SIGNAL(stateChanged(Phonon::State, Phonon::State)), SLOT(_k_stateChanged(Phonon::State, Phonon::State)));
         connect(&d->playButton, SIGNAL(clicked()), media, SLOT(play()));
         connect(&d->pauseButton, SIGNAL(clicked()), media, SLOT(pause()));
     }
